==> oplist_v2.1.583.tgz: oplist/admin/send-email.php <==
<?php
    ini_set("display_errors", "1");
    error_reporting(E_ALL);
?>
<html>
    <head>
        <meta http-equiv="content-type" content="text/html; charset=utf-8">
        <META NAME="robots" CONTENT="index,follow">
        <META NAME="title" CONTENT="Test Emailversand">
        <META NAME="audience" CONTENT="Alle">
        <title>
            Test Emailversand
        </title>
    </head>

    <body>
        <center>
            <table border="0" width="600">
                <tr>
                    <td>
                        <?php
                        if (isset($_POST['EMAIL'])) {
                            $email['FROMMAIL'] = "yourname@yourdomain.com";
                            $email['SUBJECT'] = "Test Emailversand von OPList";
                            $email['MSG'] = "<html><body><div style='font-size: 14pt;'>Wenn Sie diese Nachricht erhalten haben,</div><div style='font-size: 14pt;'>dann ist Email auf Ihrem Server richtig konfiguriert.</div><div style='font-size: 14pt;'>&nbsp;</div><div style='font-size: 14pt;'><a href=http://www.orf.at/ target=_blank>Testlink</a></div></body></html>";
                            $email['HEADERS'] = "Content-type: text/html; charset=utf-8\n";
                            $email['HEADERS'] .= "Return-path: ".$_POST['ABSENDER']."\n";
                            $email['HEADERS'] .= "From: <".$_POST['ABSENDER'].">\n";
                            $email['HEADERS'] .= "Reply-To: <".$_POST['ABSENDER'].">\n";
                            $email['TOMAIL'] = $_POST['EMAIL'];

                            @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                            ?>
                            <h1 align="center">Es wurde eine Email an <?php echo $_POST['EMAIL'];?> gesendet.</h1>
                            <a href="send-email.php">zurück</a>
                            <?php
                        } else { ?>
                            <h1 align="center">Bitte geben Sie Ihre Emailadresse ein</h1>
                            <form method=post action="send-email.php">
                                <input type=text name=EMAIL size=30 value="Empfängeremailadresse">
                                <input type=text name=ABSENDER size=30 value="Absenderemailadresse">
                                <input type=submit value="Email senden">
                            </form>
                        <?php
                        } ?>
                        <?php
                        ?>
                    </td>
                </tr>
            </table>
        </center>
    </body>
</html>

==> oplist_v15.01.734.tgz: oplist/admin/send-email.php <==
<?php
    ini_set("display_errors", "1");
    error_reporting(E_ALL);
?>
<html>
    <head>
        <meta http-equiv="content-type" content="text/html; charset=utf-8">
        <META NAME="robots" CONTENT="index,follow">
        <META NAME="title" CONTENT="Test Emailversand">
        <META NAME="audience" CONTENT="Alle">
        <title>
            Test Emailversand
        </title>
    </head>

    <body>
        <center>
            <table border="0" width="600">
                <tr>
                    <td>
                        <?php
                        if (isset($_POST['EMAIL'])) {
                            $email['FROMMAIL'] = "yourname@yourdomain.com";
                            $email['SUBJECT'] = "Test Emailversand von OPList";
                            $email['MSG'] = "<html><body><div style='font-size: 14pt;'>Wenn Sie diese Nachricht erhalten haben,</div><div style='font-size: 14pt;'>dann ist Email auf Ihrem Server richtig konfiguriert.</div><div style='font-size: 14pt;'>&nbsp;</div><div style='font-size: 14pt;'><a href=http://www.orf.at/ target=_blank>Testlink</a></div></body></html>";
                            $email['HEADERS'] = "Content-type: text/html; charset=utf-8\n";
                            $email['HEADERS'] .= "Return-path: ".$_POST['ABSENDER']."\n";
                            $email['HEADERS'] .= "From: <".$_POST['ABSENDER'].">\n";
                            $email['HEADERS'] .= "Reply-To: <".$_POST['ABSENDER'].">\n";
                            $email['TOMAIL'] = $_POST['EMAIL'];

                            if (!@mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS'])) {
								?>
								<h1 align="center">Es wurde KEINE Email an <?php echo $_POST['EMAIL'];?> gesendet.</h1>
								<h2 align="center"><?php echo error_get_last();?> </h2>
								<h2 align="center"><?php echo error_message;?> </h2>
								<?php
							} else {
								?>
								<h1 align="center">Es wurde eine Email an <?php echo $_POST['EMAIL'];?> gesendet.</h1>
								<?php
							}
                            ?>
                            <a href="send-email.php">zurück</a>
                            <?php
                        } else { ?>
                            <h1 align="center">Bitte geben Sie Ihre Emailadresse ein</h1>
                            <form method=post action="send-email.php">
                                <input type=text name=EMAIL size=30 value="Empfängeremailadresse">
                                <input type=text name=ABSENDER size=30 value="Absenderemailadresse">
                                <input type=submit value="Email senden">
                            </form>
                        <?php
                        } ?>
                        <?php
                        ?>
                    </td>
                </tr>
            </table>
        </center>
    </body>
</html>
